#!/usr/bin/python3

from subprocess import run
from platform import system


def test_service_names(streaming_config):
    """
    Tests the service names in the configuration.

    :param streaming_config: the configuration fixture collected from conftest.py
    """

    assert streaming_config['hosts'][0]['name'] == 'clmc-service', "Invalid service name: {0}".format(streaming_config['hosts'][0]['name'])
    assert streaming_config['hosts'][1]['name'] == 'nginx1', "Invalid service name: {0}".format(streaming_config['hosts'][1]['name'])
    assert streaming_config['hosts'][2]['name'] == 'nginx2', "Invalid service name: {0}".format(streaming_config['hosts'][2]['name'])
    assert streaming_config['hosts'][3]['name'] == 'loadtest-streaming', "Invalid service name: {0}".format(streaming_config['hosts'][3]['name'])

    print("\nSuccessfully passed service names configuration test\n")


def test_ping(streaming_config):
    """
    Pings each service to test for liveliness

    :param streaming_config: the configuration fixture collected from conftest.py
    """

    print("\n")  # blank line printed for formatting purposes

    ping_count = 1
    system_dependent_param = "-n" if system().lower() == "windows" else "-c"

    for service in streaming_config['hosts']:
        command = ["ping", system_dependent_param, str(ping_count), service['ip_address']]
        assert run(command).returncode == 0, "Service ping test failed for {0}".format(service['name'])
        print("\nSuccessfully passed ping test for service: {0}\n".format(service['name']))
